<?php

class pisol_variable_product{
    function __construct(){
        // 1. Add custom field input @ Product Data > Variations > Single Variation
        add_action( 'woocommerce_variation_options_pricing', array($this,'add_custom_field_to_variations'), 10, 3 );

        // 2. Save custom field on product variation save
        add_action( 'woocommerce_save_product_variation', array($this,'save_custom_field_variations'), 10, 2 );

        // 3. Store custom field value into variation data
        add_filter( 'woocommerce_available_variation', array($this,'add_custom_field_variation_data') );
    }

    function add_custom_field_to_variations( $loop, $variation_data, $variation ) {
        woocommerce_wp_text_input( array(
        'id' => 'pisol_preparation_days[' . $loop . ']',
        'class' => 'short',
        'type' => 'number',
        'label' => __( 'Preparation days', 'woocommerce' ),
        'value' => get_post_meta( $variation->ID, 'pisol_preparation_days', true )
        )
        );

        woocommerce_wp_text_input( array(
            'id' => 'out_of_stock_product_preparation_time[' . $loop . ']',
            'class' => 'short',
            'type' => 'number',
            'label' => __( 'Extra time added to preparation time (when product goes out of stock)', 'woocommerce' ),
            'value' => get_post_meta( $variation->ID, 'out_of_stock_product_preparation_time', true ),
            'desc_tip' => true,
				'description' => __( 'This will be added in the normal product preparation time when product is out of stock and you are allowing back-order ' ),
            )
            );
    }

    function save_custom_field_variations( $variation_id, $i ) {
        $pisol_preparation_days = $_POST['pisol_preparation_days'][$i];
        if ( isset( $pisol_preparation_days ) ){
            update_post_meta( $variation_id, 'pisol_preparation_days', esc_attr( $pisol_preparation_days ) );
        } else{
            update_post_meta( $variation_id, 'pisol_preparation_days', 0 );
        }
        

        $out_of_stock_product_preparation_time = $_POST['out_of_stock_product_preparation_time'][$i];
        if ( isset( $out_of_stock_product_preparation_time ) ){
            update_post_meta( $variation_id, 'out_of_stock_product_preparation_time', esc_attr( $out_of_stock_product_preparation_time ) );
        }else{
            update_post_meta( $variation_id, 'out_of_stock_product_preparation_time',0 );
        }
    }

    function add_custom_field_variation_data( $variations ) {
        $variations['pisol_preparation_days'] = '<div class="woocommerce_pisol_preparation_days">Preparation days: <span>' . get_post_meta( $variations[ 'variation_id' ], 'pisol_preparation_days', true ) . '</span></div>';
        return $variations;
    }

    static function  getVariations($product_id){
        $product = wc_get_product($product_id);
        $variations = array();
        if($product->is_type( 'variable' )){
            $variations = $product->get_available_variations();
        }
        return $variations;
    }

    static function getVariationPreparationTime($variation_id){
        $preparation_time = get_post_meta( $variation_id, 'pisol_preparation_days', true );
        if($preparation_time == ""){
            return 0;
        }
        return (int)$preparation_time;
    }
}

new pisol_variable_product();